@@ -2,6 +2,7 @@ package cluster
 
 import (
 	"github.com/spf13/cobra"
+	checkManifestUsageCmd "gitlab.com/gitlab-org/cli/commands/cluster/agent/check_manifest_usage"
 	agentGetTokenCmd "gitlab.com/gitlab-org/cli/commands/cluster/agent/get_token"
 	agentListCmd "gitlab.com/gitlab-org/cli/commands/cluster/agent/list"
 	agentUpdateKubeconfigCmd "gitlab.com/gitlab-org/cli/commands/cluster/agent/update_kubeconfig"
@@ -20,6 +21,7 @@ func NewCmdAgent(f *cmdutils.Factory) *cobra.Command {
 	agentCmd.AddCommand(agentListCmd.NewCmdAgentList(f))
 	agentCmd.AddCommand(agentGetTokenCmd.NewCmdAgentGetToken(f))
 	agentCmd.AddCommand(agentUpdateKubeconfigCmd.NewCmdAgentUpdateKubeconfig(f))
+	agentCmd.AddCommand(checkManifestUsageCmd.NewCmdCheckManifestUsage(f))
 
 	return agentCmd
 }
